Visual Saliency-based Index (VSI)
=================================

.. automodule:: viqa.fr_metrics.vsi
    :exclude-members: VSI


.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.vsi

.. autosummary::
    :toctree: generated/
    :template: class.rst

    VSI